@@ -21,10 +21,10 @@ impl<T: Serialize + DeserializeOwned> Decoder for GenericLinesCodec<T> {
 
         let maybe_str = match str_result {
             Ok(s) => s,
-            Err(err) => return Err(
+            Err(_err) => return Err(
                 Error::new(
                     ErrorKind::InvalidData,
-                    format!("Cannot decode input: {:?}.", err),
+                    format!("Cannot decode input: {:0>2X?}.", buf),
                 ),
             ),
         };
@@ -35,7 +35,12 @@ impl<T: Serialize + DeserializeOwned> Decoder for GenericLinesCodec<T> {
         };
 
         let message: T = serde_json::from_str(&string)
-            .expect("Cannot deserialize bytes to message.");
+            .expect(
+                &format!(
+                    "Cannot deserialize string to message: {:?}.",
+                    &string,
+                ),
+            );
 
         return Ok(Some(message));
     } 
