@@ -19,16 +19,16 @@ impl<T: Serialize + DeserializeOwned> Encoder<T> for GenericLinesCodec<T> {
         
         let result = Encoder::encode(
             &mut self.length_delimited_codec, 
-            data,
+            &data,
             dist_buff,
         );
 
         match result {
             Ok(_) => return Ok(()),
-            Err(err) => return Err(
+            Err(_err) => return Err(
                 Error::new(
                     ErrorKind::InvalidData,
-                    format!("Cannot encode message: {:?}.", err),
+                    format!("Cannot encode message: {:?}.", &data),
                 ),
             ),
         };
